Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 104 fields pub PORT0: Port0, pub PORT1: Port1, pub PORT2: Port1, pub PORT3: Port1, pub PORT4: Port1, pub PORT5: Port0, pub PORT6: Port0, pub PORT7: Port0, pub PORT8: Port0, pub PORT9: Port0, pub PORTA: Port0, pub PORTB: Port0, pub PFS: Pfs, pub PMISC: Pmisc, pub SPI0: Spi0, pub SPI1: Spi0, pub GPT_OPS: GptOps, pub GPT32EH0: Gpt32Eh0, pub GPT32EH1: Gpt32Eh0, pub GPT32EH2: Gpt32Eh0, pub GPT32EH3: Gpt32Eh0, pub GPT32E4: Gpt32Eh0, pub GPT32E5: Gpt32Eh0, pub GPT32E6: Gpt32Eh0, pub GPT32E7: Gpt32Eh0, pub USBHS: Usbhs, pub SCI0: Sci0, pub SCI1: Sci0, pub SCI2: Sci0, pub SCI3: Sci0, pub SCI4: Sci0, pub SCI5: Sci0, pub SCI6: Sci0, pub SCI7: Sci0, pub SCI8: Sci0, pub SCI9: Sci0, pub IIC0: Iic0, pub IIC1: Iic1, pub IIC2: Iic1, pub SYSTEM: System, pub EDMAC0: Edmac0, pub ETHERC0: Etherc0, pub SDHI0: Sdhi0, pub SDHI1: Sdhi0, pub CRC: Crc, pub CTSU: Ctsu, pub MMPU: Mmpu, pub SMPU: Smpu, pub SPMON: Spmon, pub ADC120: Adc120, pub ADC121: Adc121, pub MSTP: Mstp, pub GPT328: Gpt328, pub GPT329: Gpt328, pub GPT3210: Gpt328, pub GPT3211: Gpt328, pub GPT3212: Gpt328, pub GPT3213: Gpt328, pub RTC: Rtc, pub SSIE0: Ssie0, pub SSIE1: Ssie0, pub USBFS: Usbfs, pub SRCRAM: Srcram, pub SRC: Src, pub ICU: Icu, pub SRAM: Sram, pub GPT_ODC: GptOdc, pub AGT0: Agt0, pub AGT1: Agt0, pub FCACHE: Fcache, pub BUS: Bus, pub DAC12: Dac12, pub AMI: Ami, pub POEG: Poeg, pub IRDA: Irda, pub CAN0: Can0, pub CAN1: Can0, pub PDC: Pdc, pub QSPI: Qspi, pub MMF: Mmf, pub DMAC0: Dmac0, pub DMAC1: Dmac0, pub DMAC2: Dmac0, pub DMAC3: Dmac0, pub DMAC4: Dmac0, pub DMAC5: Dmac0, pub DMAC6: Dmac0, pub DMAC7: Dmac0, pub DMA: Dma, pub DTC: Dtc, pub DBG: Dbg, pub TSN: Tsn, pub ACMPHS0: Acmphs0, pub ACMPHS1: Acmphs1, pub ACMPHS2: Acmphs1, pub ACMPHS3: Acmphs1, pub ACMPHS4: Acmphs1, pub ACMPHS5: Acmphs1, pub ELC: Elc, pub WDT: Wdt, pub IWDT: Iwdt, pub KINT: Kint, pub DOC: Doc, pub CAC: Cac,
}
Required for compatibility with RTIC and other frameworks

Fields

PORT0: Port0PORT1: Port1PORT2: Port1PORT3: Port1PORT4: Port1PORT5: Port0PORT6: Port0PORT7: Port0PORT8: Port0PORT9: Port0PORTA: Port0PORTB: Port0PFS: PfsPMISC: PmiscSPI0: Spi0SPI1: Spi0GPT_OPS: GptOpsGPT32EH0: Gpt32Eh0GPT32EH1: Gpt32Eh0GPT32EH2: Gpt32Eh0GPT32EH3: Gpt32Eh0GPT32E4: Gpt32Eh0GPT32E5: Gpt32Eh0GPT32E6: Gpt32Eh0GPT32E7: Gpt32Eh0USBHS: UsbhsSCI0: Sci0SCI1: Sci0SCI2: Sci0SCI3: Sci0SCI4: Sci0SCI5: Sci0SCI6: Sci0SCI7: Sci0SCI8: Sci0SCI9: Sci0IIC0: Iic0IIC1: Iic1IIC2: Iic1SYSTEM: SystemEDMAC0: Edmac0ETHERC0: Etherc0SDHI0: Sdhi0SDHI1: Sdhi0CRC: CrcCTSU: CtsuMMPU: MmpuSMPU: SmpuSPMON: SpmonADC120: Adc120ADC121: Adc121MSTP: MstpGPT328: Gpt328GPT329: Gpt328GPT3210: Gpt328GPT3211: Gpt328GPT3212: Gpt328GPT3213: Gpt328RTC: RtcSSIE0: Ssie0SSIE1: Ssie0USBFS: UsbfsSRCRAM: SrcramSRC: SrcICU: IcuSRAM: SramGPT_ODC: GptOdcAGT0: Agt0AGT1: Agt0FCACHE: FcacheBUS: BusDAC12: Dac12AMI: AmiPOEG: PoegIRDA: IrdaCAN0: Can0CAN1: Can0PDC: PdcQSPI: QspiMMF: MmfDMAC0: Dmac0DMAC1: Dmac0DMAC2: Dmac0DMAC3: Dmac0DMAC4: Dmac0DMAC5: Dmac0DMAC6: Dmac0DMAC7: Dmac0DMA: DmaDTC: DtcDBG: DbgTSN: TsnACMPHS0: Acmphs0ACMPHS1: Acmphs1ACMPHS2: Acmphs1ACMPHS3: Acmphs1ACMPHS4: Acmphs1ACMPHS5: Acmphs1ELC: ElcWDT: WdtIWDT: IwdtKINT: KintDOC: DocCAC: Cac

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks